{
  lib,
  stdenv,
  fetchurl,
  autoPatchelfHook,
  dpkg,

  cups,
  gtkmm3,
  icu74,
  krb5,
  makeWrapper,
  openssl,
  pango,
  python312,
  xcb-util-cursor,
  xorg,
}:

let
  packageId = "scrt_ubuntu2464_deb_963";
in stdenv.mkDerivation rec {
  pname = "securecrt";
  version = "9.6.3";

  src = fetchurl {
    url = "https://www.vandyke.com/cgi-bin/download_1.php";
    name = "${pname}-${version}.deb";
    curlOpts = "-X POST --data 'pid=${packageId}&export_check=accept&country=no&su";
    sha256 = "sha256-PsFuxJ7H0rJCWWi+rvzrlRUJlp9R4MG14d883/kl9Lo=";
  };

  unpackCmd = "dpkg -x $curSrc source";

  nativeBuildInputs = [
    dpkg
    autoPatchelfHook
  ];

  buildInputs = [
    cups
    gtkmm3
    icu74
    krb5
    makeWrapper
    openssl
    pango
    python312
    xcb-util-cursor
    xorg.xcbutilkeysyms
    xorg.xcbutilwm
  ];

  dontConfigure = true;
  dontBuild = true;
  dontWrapQTApps = true;

  installPhase = ''
    runhook preInstall

    mkdir -p "$out"
    cp -R usr/* "$out/"
    wrapProgram "$out/bin/SecureCRT" --set QT_QPA_PLATFORM_PLUGIN_PATH "$out/lib/scrt/plugins/platforms"

    runhook postInstall
  '';

  meta = with lib; {
    homepage = "https://www.vandyke.com/products/securecrt/unix.html";
    description = "Terminal emulator for computing professionals, with advanced session management";
    license = {
      free = false;
      fullName = "Unknown / Custom";
    };

    platforms = with lib.platforms; linux ++ darwin ++ windows;
    broken = !(stdenv.hostPlatform.isLinux && stdenv.hostPlatform.isx86_64);
  };

  mainProgram = "SecureCRT";
}
