{ pkgs, lib, config, ... }:

{
  imports = [
    ./../../home/base.nix
    ./../../home/alacritty.nix
  ];

  home.packages = with pkgs; [
    # GUI Applications
    cantata
    chromium
    discord
    easyeffects
    element-desktop
    emacs-gtk
    feishin
    jellyfin-media-player
    kitty
    libreoffice
    mpv
    mumble
    orca-slicer
    papers
    pavucontrol
    picard
    prismlauncher
    restic
    runelite
    spotify
    swayimg
    thunderbird
    tor-browser
    unstable.bambu-studio
    unstable.bolt-launcher

    exiftool
    ghidra
    # pwndbg-gdb-alias # Broken in 25.05
    snicat

    # Window Manager Extras
    bibata-cursors
    cliphist
    hyprcursor
    hypridle
    hyprlock
    hyprpaper
    hyprshot
    hyprswitch
    nautilus
    networkmanager
    rofi-rbw-wayland
    swaynotificationcenter
    waybar
    wl-clipboard

    # Misc tools
    abcde
    bc
    catimg
    dante
    dig
    go
    hunspellDicts.en_US
    hunspellDicts.nb_NO
    jq
    nixpkgs-2211.remmina
    ollama-rocm
    openssl
    playerctl
    pwgen
    restic
    traceroute
    w3m

    (python313.withPackages (ps: with ps; [
      numpy
      pycryptodome
      requests
    ]))
  ];

  programs = {
    aerc = {
      enable = true;
      package = pkgs.aerc;
    };
    alacritty = {
      enable = true;
      settings.window.opacity = 0.92;
    };
    ncmpcpp.enable = true;
    neovim.plugins = with pkgs.vimPlugins; [ copilot-vim ];
    rbw = {
      enable = true;
      settings = {
        base_url = "https://pw.feal.no";
        email = "felix@albrigtsen.it";
        pinentry = pkgs.pinentry-gnome3;
      };
    };
    rofi = {
      enable = true;
      theme = "iggy";
      package = pkgs.rofi-wayland;
    };
    zsh = {
      shellAliases."rebuild" = "sudo nixos-rebuild switch --flake /config";
      prezto.pmodules = [ "ssh" ];
    };
  };

  services = {
    mpd = let
      home = config.home.homeDirectory;
    in {
      enable = true;
      musicDirectory = "${home}/mnt/music";
      dataDir = "${home}/Music/mpd/data";
      playlistDirectory = "${home}/Music/mpd/playlists";
      extraConfig = ''
        audio_output {
          type "pipewire"
          name "PipewireOut1"
        }
      '';
    };
  };

  home.pointerCursor = {
    name = "Bibata-Modern-Ice";
    package = pkgs.bibata-cursors;
    size = 24;
    gtk.enable = true;
    x11 = {
      enable = true;
      defaultCursor = true;
    };
  };

  xdg.mimeApps = {
    enable = true;

    defaultApplications = {
      "text/html" = "firefox.desktop";
      "x-scheme-handler/http" = "firefox.desktop";
      "x-scheme-handler/https" = "firefox.desktop";
      "x-scheme-handler/about" = "firefox.desktop";
      "x-scheme-handler/unknown" = "firefox.desktop";

      "inode/directory" = "org.gnome.Nautilus.desktop";
      "application/pdf" = "org.gnome.Papers.desktop";

    } // builtins.listToAttrs (
      builtins.map
        ( imgType: { name = "image/${imgType}"; value = "swayimg.desktop"; } )
        [ "apng" "bmp" "gif" "heic" "heif" "jpeg" "png" "svg" "svg+xml" "tiff" ]
    );
  };

  home.stateVersion = "24.11";
}
